@@ -1,4 +1,4 @@
-# Modified: 22 JULY 2015
+# Modified: 10 Feb 2016aaaaaaa
 
 interp <-
 function(times, y, time.out, method = 'linear', extrap = FALSE) {
@@ -6,6 +6,7 @@ function(times, y, time.out, method = 'linear', extrap = FALSE) {
   # Check arguments
   checkArgClassValue(times, c('numeric', 'integer', 'POSIXct', 'POSIXlt', 'POSIXt', 'POSIX'))
   checkArgClassValue(y, c('numeric', 'integer'))
+  checkArgClassValue(time.out, c('numeric', 'integer', 'POSIXct', 'POSIXlt', 'POSIXt', 'POSIX'))
   checkArgClassValue(method, c('character'), expected.values = c('linear', 'natural', 'hyman', 'fmm'))
   checkArgClassValue(extrap, 'logical')
 
